@@ -5,11 +5,8 @@
 #' It can be used to compare one continuous and one categorical variable, or
 #' two categorical variables, but a variation like [geom_jitter()],
 #' [geom_count()], or [geom_bin2d()] is usually more
-#' appropriate.
-#'
-#' The \emph{bubblechart} is a scatterplot with a third variable mapped to
-#' the size of points. There are no special names for scatterplots where
-#' another variable is mapped to point shape or colour, however.
+#' appropriate. A _bubblechart_ is a scatterplot with a third variable
+#' mapped to the size of points.
 #'
 #' @section Overplotting:
 #' The biggest potential problem with a scatterplot is overplotting: whenever
@@ -18,7 +15,7 @@
 #' There is no one solution to this problem, but there are some techniques
 #' that can help. You can add additional information with
 #' [geom_smooth()], [geom_quantile()] or
-#' [geom_density_2d()]. If you have few unique x values,
+#' [geom_density_2d()]. If you have few unique `x` values,
 #' [geom_boxplot()] may also be useful.
 #'
 #' Alternatively, you can
@@ -36,9 +33,8 @@
 #'   a warning. If `TRUE`, missing values are silently removed.
 #' @param ... Other arguments passed on to [layer()]. These are
 #'   often aesthetics, used to set an aesthetic to a fixed value, like
-#'   `color = "red"` or `size = 3`. They may also be parameters
+#'   `colour = "red"` or `size = 3`. They may also be parameters
 #'   to the paired geom/stat.
-#' @inheritParams layer
 #' @export
 #' @examples
 #' p <- ggplot(mtcars, aes(wt, mpg))
@@ -47,6 +43,7 @@
 #' # Add aesthetic mappings
 #' p + geom_point(aes(colour = factor(cyl)))
 #' p + geom_point(aes(shape = factor(cyl)))
+#' # A "bubblechart":
 #' p + geom_point(aes(size = qsec))
 #'
 #' # Set aesthetics to fixed value
@@ -70,23 +67,21 @@
 #' # You can create interesting shapes by layering multiple points of
 #' # different sizes
 #' p <- ggplot(mtcars, aes(mpg, wt, shape = factor(cyl)))
-#' p + geom_point(aes(colour = factor(cyl)), size = 4) +
+#' p +
+#'   geom_point(aes(colour = factor(cyl)), size = 4) +
 #'   geom_point(colour = "grey90", size = 1.5)
-#' p + geom_point(colour = "black", size = 4.5) +
+#' p +
+#'   geom_point(colour = "black", size = 4.5) +
 #'   geom_point(colour = "pink", size = 4) +
 #'   geom_point(aes(shape = factor(cyl)))
 #'
-#' # These extra layers don't usually appear in the legend, but we can
-#' # force their inclusion
-#' p + geom_point(colour = "black", size = 4.5, show.legend = TRUE) +
-#'   geom_point(colour = "pink", size = 4, show.legend = TRUE) +
-#'   geom_point(aes(shape = factor(cyl)))
-#'
 #' # geom_point warns when missing values have been dropped from the data set
 #' # and not plotted, you can turn this off by setting na.rm = TRUE
 #' mtcars2 <- transform(mtcars, mpg = ifelse(runif(32) < 0.2, NA, mpg))
-#' ggplot(mtcars2, aes(wt, mpg)) + geom_point()
-#' ggplot(mtcars2, aes(wt, mpg)) + geom_point(na.rm = TRUE)
+#' ggplot(mtcars2, aes(wt, mpg)) +
+#'   geom_point()
+#' ggplot(mtcars2, aes(wt, mpg)) +
+#'   geom_point(na.rm = TRUE)
 #' }
 geom_point <- function(mapping = NULL, data = NULL,
                        stat = "identity", position = "identity",
@@ -194,14 +189,11 @@ translate_shape_string <- function(shape_string) {
 
     more_problems <- if (n_bad > 5) {
       sprintf("\n* ... and %d more problem%s", n_bad - 5, ifelse(n_bad > 6, "s", ""))
+    } else {
+      ""
     }
 
-    stop(
-      "Can't find shape name:",
-      collapsed_names,
-      more_problems,
-      call. = FALSE
-    )
+    abort(glue("Can't find shape name:", collapsed_names, more_problems))
   }
 
   if (any(nonunique_strings)) {
@@ -221,14 +213,11 @@ translate_shape_string <- function(shape_string) {
 
     more_problems <- if (n_bad > 5) {
       sprintf("\n* ... and %d more problem%s", n_bad - 5, ifelse(n_bad > 6, "s", ""))
+    } else {
+      ""
     }
 
-    stop(
-      "Shape names must be unambiguous:",
-      collapsed_names,
-      more_problems,
-      call. = FALSE
-    )
+    abort(glue("Shape names must be unambiguous:", collapsed_names, more_problems))
   }
 
   unname(pch_table[shape_match])
