@@ -1,12 +1,13 @@
 #' Modify components of a theme
 #'
-#' Themes are a powerful way to customize the non-data components of your
-#' plots: i.e. titles, labels, fonts, background, gridlines, and legends.
-#' Themes can be used to give plots a consistent customized look.
-#' Modify a single plot's theme using `theme()`; see [theme_update()] if
-#' you want modify the active theme, to affect all subsequent plots. Theme
-#' elements are documented together according to inheritance, read more
-#' about theme inheritance below.
+#' Themes are a powerful way to customize the non-data components of your plots:
+#' i.e. titles, labels, fonts, background, gridlines, and legends. Themes can be
+#' used to give plots a consistent customized look. Modify a single plot's theme
+#' using `theme()`; see [theme_update()] if you want modify the active theme, to
+#' affect all subsequent plots. Use the themes available in [complete
+#' themes][theme_bw] if you would like to use a complete theme such as
+#' `theme_bw()`, `theme_minimal()`, and more. Theme elements are documented
+#' together according to inheritance, read more about theme inheritance below.
 #'
 #' @section Theme inheritance:
 #' Theme elements inherit properties from other theme elements hierarchically.
@@ -48,7 +49,7 @@
 #'   `axis.ticks.*` which inherits from `axis.ticks`, which in turn inherits
 #'   from `line`
 #' @param axis.ticks.length,axis.ticks.length.x,axis.ticks.length.x.top,axis.ticks.length.x.bottom,axis.ticks.length.y,axis.ticks.length.y.left,axis.ticks.length.y.right
-#' length of tick marks (`unit`)
+#'   length of tick marks (`unit`)
 #' @param axis.line,axis.line.x,axis.line.x.top,axis.line.x.bottom,axis.line.y,axis.line.y.left,axis.line.y.right
 #'   lines along axes ([element_line()]). Specify lines along all axes (`axis.line`),
 #'   lines for each plane (using `axis.line.x` or `axis.line.y`), or individually
@@ -453,6 +454,9 @@ plot_theme <- function(x, default = theme_get()) {
 #'   informative error messages.
 #' @keywords internal
 add_theme <- function(t1, t2, t2name) {
+  if (is.null(t2)) {
+    return(t1)
+  }
   if (!is.list(t2)) { # in various places in the code base, simple lists are used as themes
     abort(glue("Can't add `{t2name}` to a theme object."))
   }
